cdns = [
	'akamai.net',
	'akamaiedge.net',
	'akamaihd.net',
	'edgesuite.net',
	'edgekey.net',
	'srip.ne',
	'akamaitechnologies.com',
	'akamaitechnologies.fr',
	'llnwd.net',
	'edgecastcdn.net',
	'systemcdn.net',
	'transactcdn.net',
	'v1cdn.net',
	'v2cdn.net',
	'v3cdn.net',
	'v4cdn.net',
	'v5cdn.net',
	'hwcdn.net',
	'simplecdn.net',
	'instacontent.net',
	'footprint.net',
	'ay1.b.yahoo.com',
	'yimg.',
	'yahooapis.com',
	'google.',
	'googlesyndication.',
	'youtube.',
	'googleusercontent.com',
	'googlehosted.com',
	'gstatic.com',
	'insnw.net',
	'inscname.net',
	'internapcdn.net',
	'cloudfront.net',
	'netdna-cdn.com',
	'netdna-ssl.com',
	'netdna.com',
	'cotcdn.net',
	'cachefly.net',
	'bo.lt',
	'cloudflare.com',
	'afxcdn.net',
	'lxdns.com',
	'att-dsa.net',
	'vo.msecnd.net',
	'voxcdn.net',
	'bluehatnetwork.com',
	'swiftcdn1.com',
	'cdngc.net',
	'gccdn.net',
	'panthercdn.com',
	'fastly.net',
	'nocookie.net',
	'gslb.taobao.com',
	'gslb.tbcache.com',
	'mirror-image.net',
	'yottaa.net',
	'cubecdn.net',
	'r.cdn77.net',
	'incapdns.net',
	'bitgravity.com',
	'r.worldcdn.net',
	'r.worldssl.net',
	'tbcdn.cn',
	'taobaocdn.com',
	'ngenix.net',
	'pagerain.net',
	'ccgslb.com',
	'cdn.sfr.net',
	'azioncdn.net',
	'azioncdn.com',
	'azion.net',
	'cdncloud.net.au',
	'rncdn1.com',
	'cdnsun.net',
	'mncdn.com',
	'mncdn.net',
	'mncdn.org',
	'cdn.jsdelivr.net',
	'nyiftw.net',
	'nyiftw.com',
	'resrc.it',
	'zenedge.net',
	'lswcdn.net',
	'revcn.net',
	'revdn.net',
	'caspowa.com'
]
